Installation
============

Notes on how to install ocetrac.

##### Conda
The easiest way to install the packge is with conda: `conda install -c conda-forge ocetrac`.

##### PyPI
You can also install with pip: `pip install ocetrac`.

##### GitHub
For the most up to date version of ocetrac, you can install directly from the online repository hosted on GitLab.

1. Clone ocetrac to your local machine: `git clone https://github.com/ocetrac/ocetrac`
2. Change to the parent directory of ocetrac
3. Install ocetrac with `pip install -e ./ocetrac`. This will allow changes you make locally, to be reflected when you import the package in Python
